==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/tr.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Takvim yok.",
"No events found." => "Etkinlik yok.",
"Wrong calendar" => "Yanlış takvim",
"New Timezone:" => "Yeni Zamandilimi:",
"Timezone changed" => "Zaman dilimi değiştirildi",
"Invalid request" => "Geçersiz istek",
"Calendar" => "Takvim",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "AAA g[ yyyy]{ '&#8212;'[ AAA] g yyyy}",
"Birthday" => "Doğum günü",
"Business" => "İş",
"Call" => "Arama",
"Clients" => "Müşteriler",
"Deliverer" => "Teslimatçı",
"Holidays" => "Tatil günleri",
"Ideas" => "Fikirler",
"Journey" => "Seyahat",
"Jubilee" => "Yıl dönümü",
"Meeting" => "Toplantı",
"Other" => "Diğer",
"Personal" => "Kişisel",
"Projects" => "Projeler",
"Questions" => "Sorular",
"Work" => "İş",
"unnamed" => "isimsiz",
"Does not repeat" => "Tekrar etmiyor",
"Daily" => "Günlük",
"Weekly" => "Haftalı",
"Every Weekday" => "Haftaiçi Her gün",
"Bi-Weekly" => "İki haftada bir",
"Monthly" => "Aylık",
"Yearly" => "Yıllı",
"never" => "asla",
"by occurrences" => "sıklığa göre",
"by date" => "tarihe göre",
"by monthday" => "ay günlerine göre",
"by weekday" => "hafta günlerine göre",
"Monday" => "Pazartesi",
"Tuesday" => "Salı",
"Wednesday" => "Çarşamba",
"Thursday" => "Perşembe",
"Friday" => "Cuma",
"Saturday" => "Cumartesi",
"Sunday" => "Pazar",
"events week of month" => "ayın etkinlikler haftası",
"first" => "birinci",
"second" => "ikinci",
"third" => "üçüncü",
"fourth" => "dördüncü",
"fifth" => "beşinci",
"last" => "sonuncu",
"January" => "Ocak",
"February" => "Şubat",
"March" => "Mart",
"April" => "Nisan",
"May" => "Mayıs",
"June" => "Haziran",
"July" => "Temmuz",
"August" => "Ağustos",
"September" => "Eylül",
"October" => "Ekim",
"November" => "Kasım",
"December" => "Aralık",
"by events date" => "olay tarihine göre",
"by yearday(s)" => "yıl gün(ler)ine göre",
"by weeknumber(s)" => "hafta sayı(lar)ına göre",
"by day and month" => "gün ve aya göre",
"Date" => "Tarih",
"Cal." => "Takv.",
"All day" => "Tüm gün",
"New Calendar" => "Yeni Takvim",
"Missing fields" => "Eksik alanlar",
"Title" => "Başlık",
"From Date" => "Bu Tarihten",
"From Time" => "Bu Saatten",
"To Date" => "Bu Tarihe",
"To Time" => "Bu Saate",
"The event ends before it starts" => "Olay başlamadan önce bitiyor",
"There was a database fail" => "Bir veritabanı başarısızlığı oluştu",
"Week" => "Hafta",
"Month" => "Ay",
"List" => "Liste",
"Today" => "Bugün",
"Calendars" => "Takvimler",
"There was a fail, while parsing the file." => "Dosya okunurken başarısızlık oldu.",
"Choose active calendars" => "Aktif takvimleri seçin",
"Your calendars" => "Takvimleriniz",
"CalDav Link" => "CalDav Bağlantısı",
"Shared calendars" => "Paylaşılan",
"No shared calendars" => "Paylaşılan takvim yok",
"Share Calendar" => "Takvimi paylaş",
"Download" => "İndir",
"Edit" => "Düzenle",
"Delete" => "Sil",
"shared with you by" => "sizinle paylaşılmış",
"New calendar" => "Yeni takvim",
"Edit calendar" => "Takvimi düzenle",
"Displayname" => "Görünüm adı",
"Active" => "Aktif",
"Calendar color" => "Takvim rengi",
"Save" => "Kaydet",
"Submit" => "Gönder",
"Cancel" => "İptal",
"Edit an event" => "Bir olay düzenle",
"Export" => "Dışa aktar",
"Eventinfo" => "Etkinlik bilgisi",
"Repeating" => "Tekrarlama",
"Alarm" => "Alarm",
"Attendees" => "Katılanlar",
"Share" => "Paylaş",
"Title of the Event" => "Olayın Başlığı",
"Category" => "Kategori",
"Separate categories with commas" => "Kategorileri virgülle ayırın",
"Edit categories" => "Kategorileri düzenle",
"All Day Event" => "Tüm Gün Olay",
"From" => "Kimden",
"To" => "Kime",
"Advanced options" => "Gelişmiş opsiyonlar",
"Location" => "Konum",
"Location of the Event" => "Olayın Konumu",
"Description" => "Açıklama",
"Description of the Event" => "Olayın Açıklaması",
"Repeat" => "Tekrar",
"Advanced" => "Gelişmiş",
"Select weekdays" => "Hafta günlerini seçin",
"Select days" => "Günleri seçin",
"and the events day of year." => "ve yılın etkinlikler günü.",
"and the events day of month." => "ve ayın etkinlikler günü.",
"Select months" => "Ayları seç",
"Select weeks" => "Haftaları seç",
"and the events week of year." => "ve yılın etkinkinlikler haftası.",
"Interval" => "Aralık",
"End" => "Son",
"occurrences" => "olaylar",
"Import a calendar file" => "Takvim dosyasını içeri aktar",
"Please choose the calendar" => "Lütfen takvimi seçin",
"create a new calendar" => "Yeni bir takvim oluştur",
"Name of new calendar" => "Yeni takvimin adı",
"Import" => "İçe Al",
"Importing calendar" => "Takvim içe aktarılıyor",
"Calendar imported successfully" => "Takvim başarıyla içe aktarıldı",
"Close Dialog" => "Diyalogu kapat",
"Create a new event" => "Yeni olay oluştur",
"View an event" => "Bir olay görüntüle",
"No categories selected" => "Kategori seçilmedi",
"Select category" => "Kategori seçin",
"of" => "nın",
"at" => "üzerinde",
"Timezone" => "Zaman dilimi",
"Check always for changes of the timezone" => "Sürekli zaman dilimi değişikliklerini kontrol et",
"Timeformat" => "Saat biçimi",
"24h" => "24s",
"12h" => "12s",
"First day of the week" => "Haftanın ilk günü",
"Calendar CalDAV syncing address:" => "CalDAV Takvim eşzamanlama adresi:",
"Users" => "Kullanıcılar",
"select users" => "kullanıcıları seç",
"Editable" => "Düzenlenebilir",
"Groups" => "Gruplar",
"select groups" => "grupları seç",
"make public" => "kamuyla paylaş"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/tr.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Bütün takvimler tamamen  ön belleğe alınmadı",
"Everything seems to be completely cached" => "Bütün herşey tamamen ön belleğe alınmış görünüyor",
"No calendars found." => "Takvim yok.",
"No events found." => "Etkinlik yok.",
"Wrong calendar" => "Yanlış takvim",
"The file contained either no events or all events are already saved in your calendar." => "Dosya ya hiçbir etkinlik içermiyor veya bütün etkinlikler takviminizde zaten saklı.",
"events has been saved in the new calendar" => "Etkinlikler yeni takvimde saklandı",
"Import failed" => "İçeri aktarma başarısız oldu.",
"events has been saved in your calendar" => "Etkinlikler takviminizde saklandı",
"New Timezone:" => "Yeni Zamandilimi:",
"Timezone changed" => "Zaman dilimi değiştirildi",
"Invalid request" => "Geçersiz istek",
"Calendar" => "Takvim",
"Editable" => "Düzenlenebilir",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "AAA g[ yyyy]{ '&#8212;'[ AAA] g yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "Doğum günü",
"Business" => "İş",
"Call" => "Arama",
"Clients" => "Müşteriler",
"Deliverer" => "Teslimatçı",
"Holidays" => "Tatil günleri",
"Ideas" => "Fikirler",
"Journey" => "Seyahat",
"Jubilee" => "Yıl dönümü",
"Meeting" => "Toplantı",
"Other" => "Diğer",
"Personal" => "Kişisel",
"Projects" => "Projeler",
"Questions" => "Sorular",
"Work" => "İş",
"by" => "hazırlayan",
"unnamed" => "isimsiz",
"New Calendar" => "Yeni Takvim",
"Does not repeat" => "Tekrar etmiyor",
"Daily" => "Günlük",
"Weekly" => "Haftalı",
"Every Weekday" => "Haftaiçi Her gün",
"Bi-Weekly" => "İki haftada bir",
"Monthly" => "Aylık",
"Yearly" => "Yıllı",
"never" => "asla",
"by occurrences" => "sıklığa göre",
"by date" => "tarihe göre",
"by monthday" => "ay günlerine göre",
"by weekday" => "hafta günlerine göre",
"Monday" => "Pazartesi",
"Tuesday" => "Salı",
"Wednesday" => "Çarşamba",
"Thursday" => "Perşembe",
"Friday" => "Cuma",
"Saturday" => "Cumartesi",
"Sunday" => "Pazar",
"events week of month" => "ayın etkinlikler haftası",
"first" => "birinci",
"second" => "ikinci",
"third" => "üçüncü",
"fourth" => "dördüncü",
"fifth" => "beşinci",
"last" => "sonuncu",
"January" => "Ocak",
"February" => "Şubat",
"March" => "Mart",
"April" => "Nisan",
"May" => "Mayıs",
"June" => "Haziran",
"July" => "Temmuz",
"August" => "Ağustos",
"September" => "Eylül",
"October" => "Ekim",
"November" => "Kasım",
"December" => "Aralık",
"by events date" => "olay tarihine göre",
"by yearday(s)" => "yıl gün(ler)ine göre",
"by weeknumber(s)" => "hafta sayı(lar)ına göre",
"by day and month" => "gün ve aya göre",
"Date" => "Tarih",
"Cal." => "Takv.",
"Sun." => "Paz.",
"Mon." => "Pzt.",
"Tue." => "Sal.",
"Wed." => "Çar.",
"Thu." => "Per.",
"Fri." => "Cum.",
"Sat." => "Cmt.",
"Jan." => "Oca.",
"Feb." => "Şbt.",
"Mar." => "Mar.",
"Apr." => "Nis",
"May." => "May.",
"Jun." => "Haz.",
"Jul." => "Tem.",
"Aug." => "Agu.",
"Sep." => "Eyl.",
"Oct." => "Eki.",
"Nov." => "Kas.",
"Dec." => "Ara.",
"All day" => "Tüm gün",
"Missing fields" => "Eksik alanlar",
"Title" => "Başlık",
"From Date" => "Bu Tarihten",
"From Time" => "Bu Saatten",
"To Date" => "Bu Tarihe",
"To Time" => "Bu Saate",
"The event ends before it starts" => "Olay başlamadan önce bitiyor",
"There was a database fail" => "Bir veritabanı başarısızlığı oluştu",
"Week" => "Hafta",
"Month" => "Ay",
"List" => "Liste",
"Today" => "Bugün",
"Settings" => "Ayarlar",
"Your calendars" => "Takvimleriniz",
"CalDav Link" => "CalDav Bağlantısı",
"Share Calendar" => "Takvimi paylaş",
"Download" => "İndir",
"Edit" => "Düzenle",
"Delete" => "Sil",
"shared with you by" => "sizinle paylaşılmış",
"New calendar" => "Yeni takvim",
"Edit calendar" => "Takvimi düzenle",
"Displayname" => "Görünüm adı",
"Active" => "Aktif",
"Calendar color" => "Takvim rengi",
"Save" => "Kaydet",
"Submit" => "Gönder",
"Cancel" => "İptal",
"Edit an event" => "Bir olay düzenle",
"Export" => "Dışa aktar",
"Eventinfo" => "Etkinlik bilgisi",
"Repeating" => "Tekrarlama",
"Alarm" => "Alarm",
"Attendees" => "Katılanlar",
"Share" => "Paylaş",
"Title of the Event" => "Olayın Başlığı",
"Category" => "Kategori",
"Separate categories with commas" => "Kategorileri virgülle ayırın",
"Edit categories" => "Kategorileri düzenle",
"All Day Event" => "Tüm Gün Olay",
"From" => "Kimden",
"To" => "Kime",
"Advanced options" => "Gelişmiş opsiyonlar",
"Location" => "Konum",
"Location of the Event" => "Olayın Konumu",
"Description" => "Açıklama",
"Description of the Event" => "Olayın Açıklaması",
"Repeat" => "Tekrar",
"Advanced" => "Gelişmiş",
"Select weekdays" => "Hafta günlerini seçin",
"Select days" => "Günleri seçin",
"and the events day of year." => "ve yılın etkinlikler günü.",
"and the events day of month." => "ve ayın etkinlikler günü.",
"Select months" => "Ayları seç",
"Select weeks" => "Haftaları seç",
"and the events week of year." => "ve yılın etkinkinlikler haftası.",
"Interval" => "Aralık",
"End" => "Son",
"occurrences" => "olaylar",
"create a new calendar" => "Yeni bir takvim oluştur",
"Import a calendar file" => "Takvim dosyasını içeri aktar",
"Please choose a calendar" => "Lütfen takvim seçiniz",
"Name of new calendar" => "Yeni takvimin adı",
"Take an available name!" => "Müsait ismi al !",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Bu isimde bir takvim zaten mevcut. Yine de devam ederseniz bu takvimler birleştirilecektir.",
"Import" => "İçe Al",
"Close Dialog" => "Diyalogu kapat",
"Create a new event" => "Yeni olay oluştur",
"View an event" => "Bir olay görüntüle",
"No categories selected" => "Kategori seçilmedi",
"of" => "nın",
"at" => "üzerinde",
"General" => "Genel",
"Timezone" => "Zaman dilimi",
"Update timezone automatically" => "Otomatik saatdilimi güncelle",
"Time format" => "Saat biçimi",
"24h" => "24s",
"12h" => "12s",
"Start week on" => "Haftabaşı",
"Cache" => "Önbellek",
"Clear cache for repeating events" => "Tekrar eden etkinlikler için ön belleği temizle.",
"URLs" => "URL'ler",
"Calendar CalDAV syncing addresses" => "CalDAV takvimi adresleri senkronize ediyor.",
"more info" => "daha fazla bilgi",
"Primary address (Kontact et al)" => "Öncelikli adres",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Sadece okunabilir iCalendar link(ler)i"
);
